# Ukedown package

Ukedown is a series of extensions to the standard [Markdown library](https://github.com/waylan/Python-Markdown/tree/master/markdown) which is documented [here](https://pythonhosted.org/Markdown/extensions/api.html)

It is intended to simplify songsheet (and songbook) generation for ukulele (although it work work well for other stringed instruments too), allowing songsheets to be written as plain text, which will be converted to HTML (via markdown) and thence to PDF.

All output styling will be done using CSS - examples of this are available (with a toolset to use ukedown) from the [ukebook-md repository](https://github.com/lanky/ukebook-md)

basic CSS to demonstrate is to be found in the 'css' subdir of the ukedown package itself.

